==> am_mod_grp_0_1.tar.gz: am_mod_grp_0_1/components/grp/language/1/barnraiser_01/forum_subject_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/grp_common.inc.php');


// HEADER
$lang['hdr_choose_subject'] =				"choose a discussion title";
$lang['hdr_group_edit'] =					"edit group";


// SUBMIT
$lang['sub_search_title'] = 				"create discussion";
$lang['sub_edit_subject'] = 				"continue to create discussion";
$lang['sub_mark'] = 						"bookmark discussions and return to group";
$lang['sub_preview'] =                      "preview";
$lang['sub_update'] =                       "update";


// ERROR MESSAGES
$lang['error']['no_title'] = 				"You have not entered a topic title.";
$lang['error']['no_synopsis'] = 			"You have not entered a topic synopsis.";


//BODY TEXT
$lang['txt_synopsis'] = 					"synopsis";
$lang['txt_body'] = 						"details";
$lang['txt_image'] = 						"picture";
$lang['txt_none'] = 						"none";
$lang['txt_title_intro'] = 					"Type in the title of your discussion.";
$lang['txt_title'] = 						"title";
$lang['txt_sticky'] = 						"sticky";
$lang['txt_locked'] = 						"locked";
$lang['txt_polls'] = 						"include poll";

?>

==> am_mod_grp_0_4.tar.gz: am_mod_grp_0_4/components/grp/language/1/barnraiser_01/forum_subject_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/grp_common.inc.php');


// HEADER
$lang['hdr_choose_subject'] =				"choose a discussion title";
$lang['hdr_subject_edit'] =					"edit discussion";


// SUBMIT
$lang['sub_search_title'] = 				"create discussion";
$lang['sub_edit_subject'] = 				"continue to create discussion";
$lang['sub_mark'] = 						"bookmark discussions and return to group";
$lang['sub_preview'] =                      "validate";
$lang['sub_update'] =                       "update";


// ERROR MESSAGES
$lang['error']['no_title'] = 				"You have not entered a topic title.";
$lang['error']['no_synopsis'] = 			"You have not entered a topic synopsis.";


//BODY TEXT
$lang['txt_synopsis'] = 					"synopsis";
$lang['txt_body'] = 						"details";
$lang['txt_image'] = 						"picture";
$lang['txt_none'] = 						"none";
$lang['txt_title_intro'] = 					"Type in the title of your discussion.";
$lang['txt_title'] = 						"title";
$lang['txt_sticky'] = 						"sticky";
$lang['txt_locked'] = 						"locked";
$lang['txt_polls'] = 						"include poll";

$lang['txt_file_to_upload'] = 				"file";
$lang['txt_file_to_upload_name'] = 			"filename";
$lang['txt_title_intro'] = 					"describe your discussion";
$lang['txt_title_create'] = 				"create your discussion";
$lang['txt_title_image'] = 					"add a thumbnail image to your discussion";
$lang['txt_title_save'] = 					"check and save your discussion";

?>
